@@ -1,9 +1,9 @@
 from shutil import copy
-from os.path import isdir
+from pathlib import Path
 
 from setux.core.errors import ExecError
 from setux.core.target import Target
-from . import error, info
+from . import error, info, debug
 
 
 # pylint: disable=arguments-differ
@@ -44,20 +44,33 @@ class Local(Target):
         return open(path, mode=mode.replace('w','r')).read() == content
 
     def send(self, local, remote, quiet=False):
+        local =  Path(local)
+        assert local.is_file()
+        remote = Path(remote) if remote else local
         info(f'\tsend {local} -> {remote}')
-        copy(local, remote)
+        try:
+            copy(local, remote)
+            return True
+        except:
+            return False
 
     def fetch(self, remote, local):
         info(f'\tfetch {local} <- {remote}')
-        copy(remote, local)
+        try:
+            copy(remote, local)
+            return True
+        except:
+            return False
 
     def sync(self, src, dst=None):
-        assert isdir(src)
+        assert Path(src).is_dir()
         if not src.endswith('/'): src+='/'
-        assert dst
-        self.dir(dst).set()
-        info(f'\tsync {src} -> {dst}')
-        return self.rsync(f'{src} {dst}')
+        if dst:
+            self.dir(dst).set()
+            info(f'\tsync {src} -> {dst}')
+            return self.rsync(f'{src} {dst}')
+        else:
+            debug(f'\tskipped {src} -> {dst}')
 
     def export(self, path):
         error("can't export on local")
