@@ -1,6 +1,7 @@
 from tempfile import NamedTemporaryFile
 from os.path import isdir, basename
 from importlib import import_module
+from pathlib import Path
 
 from setux.core.errors import ExecError
 from setux.core.target import Target
@@ -75,15 +76,17 @@ class SSH(Target):
         return ret, out, err
 
     def send(self, local, remote=None, quiet=False):
-        if not remote: remote = local
+        local =  Path(local)
+        assert local.is_file()
+        remote = Path(remote) if remote else local
         if not quiet: info(f'\tsend {local} -> {remote}')
-        dest = remote[:remote.rfind('/')]
-        self.run(f'mkdir -p {dest}', report='quiet')
-        self.scp(f'{local} {self.user}@{self.host}:{remote}')
+        ret, out, err = self.scp(f'{local} {self.user}@{self.host}:{remote}')
+        return ret==0
 
     def fetch(self, remote, local, quiet=False):
         if not quiet: info(f'\tfetch {local} <- {remote}')
-        self.scp(f'{self.user}@{self.host}:{remote} {local}')
+        ret, out, err = self.scp(f'{self.user}@{self.host}:{remote} {local}')
+        return ret==0
 
     def rsync_opt(self):
         if self.priv:
@@ -95,7 +98,6 @@ class SSH(Target):
         assert isdir(src), f'\n ! sync reqires a dir ! {src} !\n'
         if not src.endswith('/'): src+='/'
         if not dst: dst = src
-        self.distro.dir(dst[:-1]).set()
         info(f'\tsync {src} -> {dst}')
         return self.rsync(f'{src} {self.user}@{self.host}:{dst}')
 
